@@ -22,7 +22,7 @@ def grade_entropy(X: np.ndarray) -> np.float64:
     This function computes
 
     .. math::
-        H_g = -\\sum_{i=1}^{m} p \\circ g(x_i) \\ln (p \\circ g(x_i))
+        H_g = \\frac{-\\sum_{i=1}^{m} p \\circ g(x_i) \\ln (p \\circ g(x_i))}{\\ln{m}}
 
     where :math:`p` is a probability distribution over the grades :math:`g`
     of the point :math:`x_i` among the indexed set of points :math:`i \\in \\{1, \\cdots, m\\}`
@@ -45,6 +45,8 @@ def grade_entropy(X: np.ndarray) -> np.float64:
     .. [3] "Partially Ordered Set.", https://en.wikipedia.org/wiki/Partially_ordered_set
     .. [4] "Partially Ordered Set.", https://mathworld.wolfram.com/PartiallyOrderedSet.html
     .. [5] "Product Order.", https://en.wikipedia.org/wiki/Product_order
+    .. [6] "Ranked Poset.", https://en.wikipedia.org/wiki/Ranked_poset
+    .. [7] "Total Order.", https://en.wikipedia.org/wiki/Total_order
 
     Examples
     --------
@@ -81,7 +83,7 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
     This function estimates
 
     .. math::
-        \\text{Dev}_p \\left[ X \\right] \\triangleq \\sqrt[p]{\\mathbb{E}\\left[ |X - \\mathbb{E}[X]| \\right]}
+        \\text{Dev}_p \\left[ X \\right] \\triangleq \\sqrt[p]{\\mathbb{E}\\left[ |X - \\mathbb{E}[X]|^p \\right]}
 
     Parameters
     ----------
@@ -126,7 +128,7 @@ def reflective_correlation(X: np.ndarray) -> np.float64:
 
     Parameters
     ----------
-    X : array_like
+    X : array-like
         The m x n data matrix.
 
     Returns
@@ -243,7 +245,7 @@ def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
     
     Parameters
     ----------
-        X : array_like
+        X : array-like
             m x n data matrix.
         method : {'average', 'min', 'max', 'dense', 'ordinal'}, optional
             The method used to assign ranks to tied elements.
@@ -301,12 +303,12 @@ def angular_disimilarity(X: np.ndarray) -> np.float64:
     .. math::
         \\text{angular disimilarity} \\triangleq \\frac{\\theta}{\\pi}
 
-    where : math:`\\theta` is the result of computing the arccosine on
+    where :math:`\\theta` is the result of computing the arccosine on
     the reflective correlation coefficient.
 
     Parameters
     ----------
-    X : array_like
+    X : array-like
         m x n data matrix
 
     Returns
@@ -340,9 +342,9 @@ def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
 
     Parameters
     ----------
-    X: array_like
+    X: array-like
         m x n data matrix
-    y: array_like
+    y: array-like
         m-dimensional vector of class labels
 
     Returns
@@ -377,11 +379,11 @@ def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float6
 
     Parameters
     ----------
-        x: array_like
+        x: array-like
             1-D data vector
-        y: array_like
+        y: array-like
             1-D data vector
-        X: array_like
+        X: array-like
             m x n data matrix
 
     Returns
@@ -427,7 +429,7 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
 
     Parameters
     ----------
-        X: array_like
+        X: array-like
             m x n data matrix
 
     Returns
@@ -435,6 +437,11 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
         : float
             Multisemideviation score.
 
+    See Also
+    --------
+    numpy.std : Standard deviation.
+    minkowski_deviation : Minkowski deviation of order p.
+
     References
     ----------
     .. [1] "Seminorm", https://mathworld.wolfram.com/Seminorm.html
@@ -453,7 +460,7 @@ def signum_correlation(X: np.ndarray) -> np.float64:
 
     Parameters
     ----------
-        X: array_like
+        X: array-like
             m x n data matrix
 
     Returns
@@ -503,9 +510,9 @@ def trencevski_malceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
 
     Parameters
     ----------
-    X: array_like
+    X: array-like
         m x n data matrix
-    Y: array_like
+    Y: array-like
         m x n data matrix
 
     Returns
@@ -526,6 +533,20 @@ def trencevski_malceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
 
 def wang_zheng_correlation(X: np.ndarray) -> np.float64:
     '''
+    Correlation coefficient due to Wang & Zheng 2014.
+
+    This correlation coefficient is equivalent to
+
+    .. math::
+
+        R_{wz} \\triangleq 1 - \\det (R_{n \\times n})
+
+    where :math:`R_{n \\times n}` is the correlation
+    matrix computed on a collection of n variables. In
+    other words, this correlation coefficient is the
+    complement of the determinant of the correlation
+    matrix.
+
 
     Parameters
     ----------
